@@ -5,7 +5,7 @@ from __future__ import absolute_import
 # import apis into api package
 from printnanny_api_client.api.alerts_api import AlertsApi
 from printnanny_api_client.api.auth_api import AuthApi
-from printnanny_api_client.api.auth__api import AuthApi
+from printnanny_api_client.api.auth_api import AuthApi
 from printnanny_api_client.api.client_config_api import ClientConfigApi
 from printnanny_api_client.api.devices_api import DevicesApi
 from printnanny_api_client.api.events_api import EventsApi
@@ -16,6 +16,5 @@ from printnanny_api_client.api.partners_geeks3_api import PartnersGeeks3Api
 from printnanny_api_client.api.partners_geeks3d_api import PartnersGeeks3dApi
 from printnanny_api_client.api.remote_control_api import RemoteControlApi
 from printnanny_api_client.api.schema_api import SchemaApi
-from printnanny_api_client.api.tasks_api import TasksApi
 from printnanny_api_client.api.telemetry_api import TelemetryApi
 from printnanny_api_client.api.users_api import UsersApi
